pub struct JsCompoundStateBuilder { /* private fields */ }Expand description
A builder for creating CompoundState instances from JavaScript.
The builder pattern is used here instead of Runtime Type Inferencing (downcasting) from generic
JavaScript objects because the latter required unsafe blocks or complex trait machinery that
is not well-supported by wasm-bindgen.
Implementations
Sourceimpl JsCompoundStateBuilder
impl JsCompoundStateBuilder
pub fn new() -> Self
pub fn add_real_vector_state(&mut self, state: &JsRealVectorState)
pub fn add_so2_state(&mut self, state: &JsSO2State)
pub fn add_so3_state(&mut self, state: &JsSO3State)
pub fn add_se2_state(&mut self, state: &JsSE2State)
pub fn add_se3_state(&mut self, state: &JsSE3State)
pub fn add_compound_state(&mut self, state: &JsCompoundState)
pub fn build(self) -> JsCompoundState